This module contains analysis for paper
[Valuation and Hedging of Cryptocurrency Inverse Options](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=4606748) by Artur Sepp and Vladimir Lucic

Comparision of net deltas in the paper are generated using
```python 
compare_net_delta.py
```
https://github.com/ArturSepp/StochVolModels/tree/main/my_papers/inverse_options

See the description of data and analysis in the paper.
